/*
 * defines for rawio.c
 *
 * Copyright 2000 by Gray Watson
 *
 * This file is part of the serial-util package.
 *
 * Permission to use, copy, modify, and distribute this software for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Gray Watson not be used in advertising
 * or publicity pertaining to distribution of the document or software
 * without specific, written prior permission.
 *
 * Gray Watson makes no representations about the suitability of the
 * software described herein for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * The author may be contacted at http://256.com/gray/
 *
 * $Id: rawio.h,v 1.12 2000/03/09 03:49:05 gray Exp $
 */

#ifndef __RAWIO_H__
#define __RAWIO_H__

#include <sys/time.h>
#include <sys/types.h>

/*<<<<<<<<<<  The below prototypes are auto-generated by fillproto */

/*
 * Write a BUF of LEN to filedesc FD with TIMEOUT_P.  Returns
 * serial error codes.
 */
extern
int	_rawio_write(const int fd, const void *buf, const int len,
		     struct timeval *timeout_p);

/*
 * Read from FD into BUF_P (of MAX chars) or until we reach TIMEOUT_P.
 * Pass back the # chars read in SIZE_P (if not null).  Returns
 * serial error codes.
 */
extern
int	_rawio_read(const int fd, struct timeval *timeout_p,
		    void *buf_p, int max, int *size_p);

/*
 * Interactively enter characters into LINE of MAX size from FDIN
 * passing back SIZE_P (if not null).  Echo chars to FDOUT if ECHO is
 * true, with IN_SECS input timeout and OUT_SECS out_put timeout.  The
 * user is finished with string when on of the ACCEPT chars is
 * pressed.  It is added to the ouput.  Handles \h, ^l, ^r, ^u, ^?.
 * Returns [NO]ERROR.
 */
extern
int	_rawio_prompt(const int fdin, const int fdout, char *line,
		      const int max, int *size_p, struct timeval *in_p,
		      struct timeval *out_p, const char *accept,
		      const char echo);

/*
 * Watch the port in FD until we see a char or timeout after SECS.
 * Returns serial error codes: SERIAL_ERROR_TIMEOUT if SECS passed or
 * SERIAL_ERROR_NONE if it read something in that time.
 */
extern
int	_rawio_watch(const int fd, struct timeval *timeout_p);

/*<<<<<<<<<<   This is end of the auto-generated output from fillproto. */

#endif /* ! __RAWIO_H__ */
