/*
 * header file for script routines.
 *
 * Copyright 2000 by Gray Watson
 *
 * This file is part of the serial-util package.
 *
 * Permission to use, copy, modify, and distribute this software for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Gray Watson not be used in advertising
 * or publicity pertaining to distribution of the document or software
 * without specific, written prior permission.
 *
 * Gray Watson makes no representations about the suitability of the
 * software described herein for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * The author may be contacted at http://256.com/gray/
 *
 * $Id: script.h,v 1.16 2000/03/09 03:49:05 gray Exp $
 */

#ifndef __SCRIPT_H__
#define __SCRIPT_H__

#include "serial.h"			/* for serial_arg_t */
#include "serial_loc.h"			/* for serial_t */

/*<<<<<<<<<<  The below prototypes are auto-generated by fillproto */

/*
 * Free the lines and any line allocations from SERIAL_P.
 */
extern
void   _script_free_lines(serial_t *serial_p);

/*
 * Free the lines and any line allocations from SERIAL_P.
 */
extern
void   _script_free_labels(serial_t *serial_p);

/*
 * Load a script in FILE_P, into SERIAL_P buffers while applying ARGS.
 * Returns serial error codes.
 */
extern
int	_script_load(serial_t *serial_p, FILE *file_p,
		     const serial_arg_t *args);

/*
 * Write a script in SERIAL_P to OUTFILE in possible BINARY format.
 * Returns serial error codes.
 */
extern
int	_script_write(serial_t *serial_p, FILE *outfile, const int type);

/*
 * Run script in SERIAL_P starting at LABEL (if null then the top of
 * file).  This passes back an error CODE_P and a pass-back STR_P (if
 * either not NULL).  Returns serial error codes.
 */
extern
int	_script_run(serial_t *serial_p, const char *label,
		    int *code_p, char **str_p);

/*
 * Lock the port in SERIAL_P. Returns serial error codes.
 */
extern
int	_script_lock(serial_t *serial_p);

/*
 * Unlock the port in SERIAL_P.  Returns serial error codes.
 */
extern
int	_script_unlock(serial_t *serial_p);

/*<<<<<<<<<<   This is end of the auto-generated output from fillproto. */

#endif /* ! __SCRIPT_H__ */
