/*
 * serial lex config file
 *
 * Copyright 2000 by Gray Watson
 *
 * This file is part of the serial-util package.
 *
 * Permission to use, copy, modify, and distribute this software for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Gray Watson not be used in advertising
 * or publicity pertaining to distribution of the document or software
 * without specific, written prior permission.
 *
 * Gray Watson makes no representations about the suitability of the
 * software described herein for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * The author may be contacted at http://256.com/gray/
 *
 * $Id: script_lex.l,v 1.10 2000/03/09 03:49:05 gray Exp $
 */

%{
#include <stdio.h>

#include "script_tok.h"				/* for token defs */

static	char	*rcs_id =
  "$Id: script_lex.l,v 1.10 2000/03/09 03:49:05 gray Exp $";

#ifdef DEBUG
/* for token counting and debugging purposes */
#define TOKEN_RETURN(v)	do { \
			  (void)printf("line %d: got token '%.*s' (%d)\n", \
				       yylineno, yyleng, yytext, v); \
			  return v; \
			} while(0)
#else /* ! DEBUG */

#define TOKEN_RETURN(v)		return v

#endif /* ! DEBUG */

#define LOWERCASE_RESERVED			/* allow lowercase commands */

/* exported variables */
int	yylineno = 1;				/* line number simulator */
%}

/* characters */
DIGIT		[0-9]
LOWER		[a-z]
UPPER		[A-Z]
LETTER		({UPPER}|{LOWER})
EOL		[\n\r]
OCTAL_DIGIT	[0-7]
HEX_DIGIT	({DIGIT}|[a-fA-F])

/* literals */
OCTAL		0{OCTAL_DIGIT}+
HEX		0x{HEX_DIGIT}+
INT		([+-])?{DIGIT}+
FLOAT		([+-])?({INT}"."{INT})|({INT}".")|("."{INT})
  
/*
 * Define the c-comment condition below
 *
 * NOTE: no space allowed after it and before %%
 */
%x ccom
%%
  
{INT}		TOKEN_RETURN(TOK_INT);

  /* match strings which can be delimited with " or ' and can contain \delim */
(\"(\\\"|[^\"])*\")|(\'(\\\'|[^\'])*\')	{
  /* this strips the quotes */
  yytext++;
  yytext[strlen(yytext) - 1] = '\0';
  TOKEN_RETURN(TOK_STRING);
}

  /* process labels and destination labels */
("_"|{LETTER}|{DIGIT})*:	TOKEN_RETURN(TOK_LABEL);

  /* general identifier or reserved word */
("_"|{LETTER})("_"|{LETTER}|{DIGIT})*    TOKEN_RETURN(TOK_RESERVED);

  /* handle and ignore c-style comments while counting the lines */
"/*"		BEGIN(ccom);
<ccom>"*/"	BEGIN(INITIAL);
<ccom>{EOL}	yylineno++;
<ccom>.		/* COMMENT */;

  /* handle and ignore pound comments and spaces */
#[^\r\n]*	/* COMMENT */;
[ \t]		/* SPACE */;

  /* handle end-of-line by counting the lines */
{EOL}		yylineno++;

  /* anything else is an error condition */
.		TOKEN_RETURN(TOK_UNKNOWN);

%%
